# OpenAQ Python SDK

!!! warning

    The OpenAQ python client is still under active development and may be unstable until
    a v1.0.0 release.

The OpenAQ Python SDK provides a Python interface for interacting the with
OpenAQ API. The library is compatible with Python versions 3.8, 3.9, 3.10, 3.11
and 3.12

Features:

- Synchronous and Asynchronous client options - clients to support standard
  synchronous function calls or asynchronous event loop with async/await.
- Comprehensive type annotations - type hinting for improve text editor hints
  and autocomplete.
- Deserialized response classes - Python object for easier attribute access,
  with options for json and dictionary representations.
